# colliderscope

[![PyPI version](https://img.shields.io/pypi/v/colliderscope.svg)](https://pypi.org/project/colliderscope/)
[![Documentation](https://readthedocs.org/projects/colliderscope/badge/?version=latest)](https://colliderscope.readthedocs.io)
[![License](https://img.shields.io/pypi/l/colliderscope)](https://raw.githubusercontent.com/jacanchaplais/colliderscope/main/LICENSE.txt)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit)](https://github.com/pre-commit/pre-commit)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)


Visualise your high energy physics (HEP) data with colliderscope!


## Installation

```
pip install colliderscope
```

## Features


More information on the API is available in the
[documentation](https://colliderscope.readthedocs.io)
